# Установка

S3 Bucket helper utils. Async list objects by folders

## Установка

## Установка pipx
[`pipx`](https://pypa.github.io/pipx/) создает изолированные среды, чтобы избежать конфликтов с 
существующими системными пакетами.

=== "MacOS"
    В терминале выполните:
    ```bash
    brew install pipx
    pipx ensurepath
    ```

=== "Linux"
    Сначала убедитесь, что Python установлен.

    Введите в терминал:

    ```bash
    python3 -m pip install --user pipx
    python3 -m pipx ensurepath
    ```

=== "Windows"
    Сначала установите Python, если он еще не установлен.

    В командной строке введите (если Python был установлен из Microsoft Store, используйте `python3` вместо `python`):
    
    ```bash
    python -m pip install --user pipx
    ```

## Установка `aws-s3`:
В терминале (командной строке) выполните:

```bash
pipx install aws-s3
```

### Дополнительно

Чтобы увидеть все параметры, используйте: 
```bash
aws-s3 --help
```